@@ -1309,12 +1309,17 @@ lldpd_loop(struct lldpd *cfg)
 static void
 lldpd_exit(struct lldpd *cfg)
 {
+	char *lockname = NULL;
 	struct lldpd_hardware *hardware, *hardware_next;
 	log_debug("main", "exit lldpd");
 
 	TAILQ_FOREACH(hardware, &cfg->g_hardware, h_entries)
 		lldpd_send_shutdown(hardware);
 
+	if (asprintf(&lockname, "%s.lock", cfg->g_ctlname) != -1) {
+		priv_ctl_cleanup(lockname);
+		free(lockname);
+	}
 	close(cfg->g_ctl);
 	priv_ctl_cleanup(cfg->g_ctlname);
 	log_debug("main", "cleanup hardware information");
@@ -1797,6 +1802,24 @@ lldpd_main(int argc, char *argv[], char *envp[])
 		log_warn("main", "unable to chmod control socket");
 #endif
 
+	/* Create associated advisory lock file */
+	char *lockname = NULL;
+	int fd;
+	if (asprintf(&lockname, "%s.lock", ctlname) == -1)
+		fatal("main", "cannot build lock name");
+	if ((fd = open(lockname, O_CREAT|O_RDWR, 0000)) == -1)
+		fatal("main", "cannot create lock file for control socket");
+	close(fd);
+#ifdef ENABLE_PRIVSEP
+	if (chown(lockname, uid, gid) == -1)
+		log_warn("main", "unable to chown control socket lock");
+	if (chmod(lockname,
+		S_IRUSR | S_IWUSR | S_IXUSR |
+		S_IRGRP | S_IWGRP | S_IXGRP) == -1)
+		log_warn("main", "unable to chmod control socket lock");
+#endif
+	free(lockname);
+
 	/* Disable SIGPIPE */
 	signal(SIGPIPE, SIG_IGN);
 
