@@ -144,6 +144,72 @@ static lldpctl_map_t operational_mau_type_values[] = {
 	{ LLDP_DOT3_MAU_100GBASESR10,   "100GbaseSR10 - 100GBASE-R PCS/PMA over 10 lane multimode fiber" },
 	{ LLDP_DOT3_MAU_100GBASELR4,	"100GbaseLR4 - 100GBASE-R PCS/PMA over 4 WDM lane single mode fiber, long reach" },
 	{ LLDP_DOT3_MAU_100GBASEER4,	"100GbaseER4 - 100GBASE-R PCS/PMA over 4 WDM lane single mode fiber PMD, extended reach" },
+	{ LLDP_DOT3_MAU_1000BASET1,	"1000baseT1 - 1000BASE-T1 single balanced twisted-pair copper cabling PHY" },
+	{ LLDP_DOT3_MAU_1000BASEPX30D,	"1000basePX30D - One single-mode fiber EPON OLT, 20km, 1:32 split ratio" },
+	{ LLDP_DOT3_MAU_1000BASEPX30U,	"1000basePX30U - One single-mode fiber EPON ONU, 20km, 1:32 split ratio" },
+	{ LLDP_DOT3_MAU_1000BASEPX40D,	"1000basePX40D - One single-mode fiber EPON OLT, 20km, 1:64 split ratio" },
+	{ LLDP_DOT3_MAU_1000BASEPX40U,	"1000basePX40U - One single-mode fiber EPON ONU, 20km, 1:64 split ratio" },
+	{ LLDP_DOT3_MAU_10G1GBASEPRXD4,	"10G1GbasePRXD4 - One single-mode fiber asymmetric-rate EPON OLT, supporting  extended power budget (PRX40)" },
+	{ LLDP_DOT3_MAU_10G1GBASEPRXU4,	"10G1GbasePRXU4 - One single-mode fiber asymmetric-rate EPON ONU, supporting  extended power budget (PRX40)" },
+	{ LLDP_DOT3_MAU_10GBASEPRD4,	"10GbasePRD4 - One single-mode fiber symmetric-rate EPON OLT, supporting  extended power budget (PR40)" },
+	{ LLDP_DOT3_MAU_10GBASEPRU4,	"10GbasePRU4 - One single-mode fiber symmetric-rate EPON ONU, supporting  extended power budget (PR40)" },
+	{ LLDP_DOT3_MAU_25GBASECR,	"25GbaseCR - 25GBASE-R PCS/PMA over shielded balanced copper cable" },
+	{ LLDP_DOT3_MAU_25GBASECRS,	"25GbaseCRS - 25GBASE-R PCS/PMA over shielded balanced copper cable  without RS-FEC" },
+	{ LLDP_DOT3_MAU_25GBASEKR,	"25GbaseKR - 25GBASE-R PCS/PMA over an electrical backplane" },
+	{ LLDP_DOT3_MAU_25GBASEKRS,	"25GbaseKRS - 25GBASE-R PCS/PMA over an electrical backplane without RS-FEC" },
+	{ LLDP_DOT3_MAU_25GBASER,	"25GbaseR - 25GBASE-R PCS/PMA over undefined PMD" },
+	{ LLDP_DOT3_MAU_25GBASESR,	"25GbaseSR - 25GBASE-R PCS/PMA over multimode fiber" },
+	{ LLDP_DOT3_MAU_25GBASET,	"25GbaseT - Four-pair twisted-pair balanced copper cabling" },
+	{ LLDP_DOT3_MAU_40GBASEER4,	"40GbaseER4 - 40GBASE-R PCS/PMA over 4 WDM lane single mode fiber" },
+	{ LLDP_DOT3_MAU_40GBASER,	"40GbaseR - 40GBASE-R PCS as over undefined PMA/PMD" },
+	{ LLDP_DOT3_MAU_40GBASET,	"40GbaseT - Four-pair twisted-pair balanced copper cabling" },
+	{ LLDP_DOT3_MAU_100GBASECR4,	"100GbaseCR4 - 100GBASE-R PCS/PMA over 4 lane shielded copper balanced cable" },
+	{ LLDP_DOT3_MAU_100GBASEKR4,	"100GbaseKR4 - 100GBASE-R PCS/PMA over an electrical backplane" },
+	{ LLDP_DOT3_MAU_100GBASEKP4,	"100GbaseKP4 - 100GBASE-P PCS/PMA over an electrical backplane PMD" },
+	{ LLDP_DOT3_MAU_100GBASER,	"100GbaseR - 100GBASE-R Multi-lane PCS over undefined PMA/PMD" },
+	{ LLDP_DOT3_MAU_100GBASESR4,	"100GbaseSR4 - 100GBASE-R PCS/PMA over 4 lane multimode fiber" },
+	{ LLDP_DOT3_MAU_2P5GIGT,	"2p5GigT - 2.5GBASE-T Four-pair twisted-pair balanced copper cabling PHY" },
+	{ LLDP_DOT3_MAU_5GIGT,		"5GigT - 5GBASE-T Four-pair twisted-pair balanced copper cabling PHY" },
+	{ LLDP_DOT3_MAU_100BASET1,	"100baseT1 - 100BASE-T1 Single balanced twisted-pair copper cabling PHY" },
+	{ LLDP_DOT3_MAU_1000BASERHA,	"1000baseRHA - 1000BASE-RHA Plastic optical fiber PHY" },
+	{ LLDP_DOT3_MAU_1000BASERHB,	"1000baseRHB - 1000BASE-RHB Plastic optical fiber PHY" },
+	{ LLDP_DOT3_MAU_1000BASERHC,	"1000baseRHC - 1000BASE-RHC Plastic optical fiber PHY" },
+	{ LLDP_DOT3_MAU_2P5GBASEKX,	"2p5GbaseKX - 2.5GBASE-X PMD over an electrical backplane" },
+	{ LLDP_DOT3_MAU_2P5GBASEX,	"2p5GbaseX - 2.5GBASE-X PCS/PMA over undefined PMD" },
+	{ LLDP_DOT3_MAU_5GBASEKR,	"5GbaseKR - 5GBASE-KR PMD over an electrical backplane" },
+	{ LLDP_DOT3_MAU_5GBASER,	"5GbaseR - 5GBASE-R PCS/PMA over undefined PMD" },
+	{ LLDP_DOT3_MAU_10GPASSXR,	"10GpassXR - Coax cable distribution network PHY continuous downstream/burst mode upstream PHY" },
+	{ LLDP_DOT3_MAU_25GBASELR,	"25GbaseLR - 25GBASE-R PCS/PMA over single-mode fiber PMD, with long reach" },
+	{ LLDP_DOT3_MAU_25GBASEER,	"25GbaseER - 25GBASE-R PCS/PMA over single-mode fiber PMD, with extended reach" },
+	{ LLDP_DOT3_MAU_50GBASER,	"50GbaseR - 50GBASE-R Multi-lane PCS over undefined PMA/PMD" },
+	{ LLDP_DOT3_MAU_50GBASECR,	"50GbaseCR - 50GBASE-R PCS/PMA over shielded copper balanced cable PMD" },
+	{ LLDP_DOT3_MAU_50GBASEKR,	"50GbaseKR - 50GBASE-R PCS/PMA over an electrical backplane PMD" },
+	{ LLDP_DOT3_MAU_50GBASESR,	"50GbaseSR - 50GBASE-R PCS/PMA over multimode fiber PMD" },
+	{ LLDP_DOT3_MAU_50GBASEFR,	"50GbaseFR - 50GBASE-R PCS/PMA over single mode fiber PMD with reach up to at least 2 km" },
+	{ LLDP_DOT3_MAU_50GBASELR,	"50GbaseLR - 50GBASE-R PCS/PMA over single mode fiber PMD with reach up to at least 10 km" },
+	{ LLDP_DOT3_MAU_50GBASEER,	"50GbaseER - 50GBASE-R PCS/PMA over single-mode fiber PMD with reach up to at least 40 km" },
+	{ LLDP_DOT3_MAU_100GBASECR2,	"100GbaseCR2 - 100GBASE-R PCS/PMA over 2 lane shielded copper balanced cable PMD" },
+	{ LLDP_DOT3_MAU_100GBASEKR2,	"100GbaseKR2 - 100GBASE-R PCS/PMA over an electrical backplane PMD" },
+	{ LLDP_DOT3_MAU_100GBASESR2,	"100GbaseSR2 - 100GBASE-R PCS/PMA over 2 lane multimode fiber PMD" },
+	{ LLDP_DOT3_MAU_100GBASEDR,	"100GbaseDR - 100GBASE-R PCS/PMA over single mode fiber PMD" },
+	{ LLDP_DOT3_MAU_200GBASER,	"200GbaseR - 200GBASE-R Multi-lane PCS over undefined PMA/PMD" },
+	{ LLDP_DOT3_MAU_200GBASEDR4,	"200GbaseDR4 - 200GBASE-R PCS/PMA over 4-lane single-mode fiber PMD" },
+	{ LLDP_DOT3_MAU_200GBASEFR4,	"200GbaseFR4 - 200GBASE-R PCS/PMA over 4 WDM lane single-mode fiber PMD with reach up to at least 2 km" },
+	{ LLDP_DOT3_MAU_200GBASELR4,	"200GbaseLR4 - 200GBASE-R PCS/PMA over 4 WDM lane single-mode fiber PMD with reach up to at least 10 km" },
+	{ LLDP_DOT3_MAU_200GBASECR4,	"200GbaseCR4 - 200GBASE-R PCS/PMA over 4 lane shielded copper balanced cable PMD" },
+	{ LLDP_DOT3_MAU_200GBASEKR4,	"200GbaseKR4 - 200GBASE-R PCS/PMA over an electrical backplane PMD" },
+	{ LLDP_DOT3_MAU_200GBASESR4,	"200GbaseSR4 - 200GBASE-R PCS/PMA over 4 lane multimode fiber PMD" },
+	{ LLDP_DOT3_MAU_200GBASEER4,	"200GbaseER4 - 200GBASE-R PCS/PMA over 4 WDM lane single-mode fiber PMD with reach up to at least 40 km" },
+	{ LLDP_DOT3_MAU_400GBASER,	"400GbaseR - 400GBASE-R Multi-lane PCS over undefined PMA/PMD" },
+	{ LLDP_DOT3_MAU_400GBASESR16,	"400GbaseSR16 - 400GBASE-R PCS/PMA over 16-lane multimode fiber PMD" },
+	{ LLDP_DOT3_MAU_400GBASEDR4,	"400GbaseDR4 - 400GBASE-R PCS/PMA over 4-lane single-mode fiber PMD" },
+	{ LLDP_DOT3_MAU_400GBASEFR8,	"400GbaseFR8 - 400GBASE-R PCS/PMA over 8 WDM lane single-mode fiber PMD with reach up to at least 2 km" },
+	{ LLDP_DOT3_MAU_400GBASELR8,	"400GbaseLR8 - 400GBASE-R PCS/PMA over 8 WDM lane single-mode fiber PMD with reach up to at least 10 km" },
+	{ LLDP_DOT3_MAU_400GBASEER8,	"400GbaseER8 - 400GBASE-R PCS/PMA over 8 WDM lane single-mode fiber PMD with reach up to at least 40 km" },
+	{ LLDP_DOT3_MAU_10BASET1L,	"10baseT1L - 10BASE-T1L Single balanced pair PHY" },
+	{ LLDP_DOT3_MAU_10BASET1SHD,	"10baseT1SHD - 10BASE-T1S Single balanced pair PHY, half duplex mode" },
+	{ LLDP_DOT3_MAU_10BASET1SMD,	"10baseT1SMD - 10BASE-T1S Single balanced pair PHY, multidrop mode" },
+	{ LLDP_DOT3_MAU_10BASET1SFD,	"10baseT1SFD - 10BASE-T1S Single balanced pair PHY, full duplex mode" },
 	{ 0, NULL }
 };
 #endif
