@@ -196,7 +196,7 @@ check_for_notification(lldpctl_conn_t *conn)
 	change = p;
 
 	/* We have a notification, call the callback */
-	if (conn->watch_cb) {
+	if (conn->watch_cb || conn->watch_cb2) {
 		switch (change->state) {
 		case NEIGHBOR_CHANGE_DELETED: type = lldpctl_c_deleted; break;
 		case NEIGHBOR_CHANGE_ADDED: type = lldpctl_c_added; break;
@@ -212,7 +212,10 @@ check_for_notification(lldpctl_conn_t *conn)
 		neighbor = _lldpctl_new_atom(conn, atom_port, 0,
 		    NULL, change->neighbor, NULL);
 		if (neighbor == NULL) goto end;
-		conn->watch_cb(conn, type, interface, neighbor, conn->watch_data);
+		if (conn->watch_cb)
+			conn->watch_cb(conn, type, interface, neighbor, conn->watch_data);
+		else
+			conn->watch_cb2(type, interface, neighbor, conn->watch_data);
 		conn->watch_triggered = 1;
 		goto end;
 	}
@@ -262,7 +265,8 @@ lldpctl_recv(lldpctl_conn_t *conn, const uint8_t *data, size_t length)
 	return conn->input_buffer_len;
 }
 
-int lldpctl_process_conn_buffer(lldpctl_conn_t *conn)
+int
+lldpctl_process_conn_buffer(lldpctl_conn_t *conn)
 {
 	int rc;
 
