@@ -231,7 +231,7 @@ int lldpctl_release(lldpctl_conn_t *conn);
  * translate this error code.
  *
  * When a function returns an integer, it may return a negative value. It
- * usually means this is an error but some functions may return a legetimate
+ * usually means this is an error but some functions may return a legitimate
  * negative value (for example @ref lldpctl_atom_get_int()). When there is a
  * doubt, @ref lldpctl_last_error() should be checked.
  *
@@ -449,7 +449,7 @@ void lldpctl_atom_dec_ref(lldpctl_atom_t *atom);
 /**
  * Possible events for a change (notification).
  *
- * @see lldpctl_watch_callback
+ * @see lldpctl_watch_callback2
  */
 typedef enum {
 	lldpctl_c_deleted,	/**< The neighbor has been deleted */
@@ -460,7 +460,7 @@ typedef enum {
 /**
  * Callback function invoked when a change is detected.
  *
- * @param conn      Connection with lldpd.
+ * @param conn      Connection with lldpd. Should not be used.
  * @param type      Type of change detected.
  * @param interface Physical interface on which the change has happened.
  * @param neighbor  Changed neighbor.
@@ -470,6 +470,10 @@ typedef enum {
  * reference count are decremented when the callback ends. If you want to keep a
  * reference to it, be sure to increment the reference count in the callback.
  *
+ * @warning The provided connection should not be used at all. Do not use @c
+ * lldpctl_atom_set_*() functions on @c interface or @c neighbor either. If you
+ * do, you will get a @c LLDPCTL_ERR_INVALID_STATE error.
+ *
  * @see lldpctl_watch_callback
  */
 typedef void (*lldpctl_change_callback)(lldpctl_conn_t *conn,
@@ -478,6 +482,25 @@ typedef void (*lldpctl_change_callback)(lldpctl_conn_t *conn,
     lldpctl_atom_t *neighbor,
     void *data);
 
+/**
+ * Callback function invoked when a change is detected.
+ *
+ * @param type      Type of change detected.
+ * @param interface Physical interface on which the change has happened.
+ * @param neighbor  Changed neighbor.
+ * @param data      Data provided when registering the callback.
+ *
+ * The provided interface and neighbor atoms are stolen by the callback: their
+ * reference count are decremented when the callback ends. If you want to keep a
+ * reference to it, be sure to increment the reference count in the callback.
+ *
+ * @see lldpctl_watch_callback2
+ */
+typedef void (*lldpctl_change_callback2)(lldpctl_change_t type,
+    lldpctl_atom_t *interface,
+    lldpctl_atom_t *neighbor,
+    void *data);
+
 /**
  * Register a callback to be called on changes.
  *
@@ -490,11 +513,35 @@ typedef void (*lldpctl_change_callback)(lldpctl_conn_t *conn,
  * and therefore will issue IO operations. The error code could then be @c
  * LLDPCTL_ERR_WOULDBLOCK.
  *
- * Once a callback is registered, the connection shouldn't be used for anything
- * else than receiving notifications.
+ * @warning Once a callback is registered, the connection shouldn't be used for
+ * anything else than receiving notifications. If you do, you will get a @c
+ * LLDPCTL_ERR_INVALID_STATE error.
+ *
+ * @deprecated This function is deprecated and lldpctl_watch_callback2 should be
+ * used instead.
  */
 int lldpctl_watch_callback(lldpctl_conn_t *conn,
     lldpctl_change_callback cb,
+    void *data) __attribute__ ((deprecated));
+
+/**
+ * Register a callback to be called on changes.
+ *
+ * @param conn Connection with lldpd.
+ * @param cb   Replace the current callback with the provided one.
+ * @param data Data that will be passed to the callback.
+ * @return 0 in case of success or -1 in case of errors.
+ *
+ * This function will register the necessity to push neighbor changes to lldpd
+ * and therefore will issue IO operations. The error code could then be @c
+ * LLDPCTL_ERR_WOULDBLOCK.
+ *
+ * @warning Once a callback is registered, the connection shouldn't be used for
+ * anything else than receiving notifications. If you do, you will get a @c
+ * LLDPCTL_ERR_INVALID_STATE error.
+ */
+int lldpctl_watch_callback2(lldpctl_conn_t *conn,
+    lldpctl_change_callback2 cb,
     void *data);
 
 /**
@@ -642,13 +689,13 @@ lldpctl_atom_t *lldpctl_get_default_port(lldpctl_conn_t *conn);
  * written. An atom marked with (IS) can be retrieved as an integer and features
  * an appropriate representation as a string (usually, the name of a constant)
  * which is more meaningful than just the integer. An atom marked as (I) can be
- * retrieved and as a string. In the later case, this is just a string
- * representation of the integer. An atom marked with (AL) can be retrieved as
- * an atom only and can be iterated over. This is usually a list of things. An
- * atom marked (I,W) can be read as an integer or a string and can be written as
- * an integer. The change would not be commited until the atom is written to the
- * nearest atom supporting (A,WO) operation (eventually with an indirection, i.e
- * first write to a (A,W), then to a (A,WO)).
+ * retrieved as an integer and as a string. In the later case, this is just a
+ * string representation of the integer. An atom marked with (AL) can be
+ * retrieved as an atom only and can be iterated over. This is usually a list of
+ * things. An atom marked (I,W) can be read as an integer or a string and can be
+ * written as an integer. The change would not be commited until the atom is
+ * written to the nearest atom supporting (A,WO) operation (eventually with an
+ * indirection, i.e first write to a (A,W), then to a (A,WO)).
  */
 typedef enum {
 	lldpctl_k_config_tx_interval, /**< `(I,WO)` Transmit interval. When set to -1, it is meant to transmit now. */
@@ -670,6 +717,7 @@ typedef enum {
 	lldpctl_k_config_chassis_mgmt_advertise, /**< `(I,WO)` Enable or disable management addresses advertisement */
 	lldpctl_k_config_cid_string,    /**< `(S,WON)` User defined string for the chassis ID */
 	lldpctl_k_config_perm_iface_pattern, /**< `(S,WON)` Pattern of permanent interfaces */
+	lldpctl_k_config_tx_interval_ms, /**< `(I,WO)` Transmit interval in milliseconds. Set to -1 to transmit now. */
 
 	lldpctl_k_interface_name = 1000, /**< `(S)` The interface name. */
 
@@ -690,6 +738,7 @@ typedef enum {
 	lldpctl_k_port_status,	   /**< `(IS,WO)` Operational status of this (local) port */
 	lldpctl_k_port_chassis,	   /**< `(A)` Chassis associated to the port */
 	lldpctl_k_port_ttl,        /**< `(I)` TTL for port, 0 if info is attached to chassis */
+	lldpctl_k_port_vlan_tx,    /**< `(I,W)` VLAN tag for TX on port, -1 VLAN disabled */
 
 	lldpctl_k_port_dot3_mfs = 1300,	   /**< `(I)` MFS */
 	lldpctl_k_port_dot3_aggregid,   /**< `(I)` Port aggregation ID */
@@ -711,6 +760,22 @@ typedef enum {
 	lldpctl_k_dot3_power_allocated, /**< `(I,W)` 802.3AT power allocated */
 	lldpctl_k_dot3_power_requested, /**< `(I,W)` 802.3AT power requested */
 
+	/* 802.3bt additions */
+	lldpctl_k_dot3_power_pd_4pid, /**< `(IS,W)` 802.3BT both modes supported? */
+	lldpctl_k_dot3_power_requested_a, /**< `(I,W)` 802.3BT power value requested for A */
+	lldpctl_k_dot3_power_requested_b, /**< `(I,W)` 802.3BT power value requested for B */
+	lldpctl_k_dot3_power_allocated_a, /**< `(I,W)` 802.3BT power value allocated for A */
+	lldpctl_k_dot3_power_allocated_b, /**< `(I,W)` 802.3BT power value allocated for B */
+	lldpctl_k_dot3_power_pse_status, /**< `(IS,W)` 802.3BT PSE powering status */
+	lldpctl_k_dot3_power_pd_status, /**< `(IS,W)` 802.3BT PD powering status */
+	lldpctl_k_dot3_power_pse_pairs_ext, /**< `(IS,W)` 802.3BT PSE power pairs */
+	lldpctl_k_dot3_power_class_a, /**< `(IS,W)` 802.3BT power class for A */
+	lldpctl_k_dot3_power_class_b, /**< `(IS,W)` 802.3BT power class for B */
+	lldpctl_k_dot3_power_class_ext, /**< `(IS,W)` 802.3BT power class */
+	lldpctl_k_dot3_power_type_ext, /**< `(IS,W)` 802.3BT power type */
+	lldpctl_k_dot3_power_pd_load, /**< `(IS,W)` 802.3BT dualsig isolated? */
+	lldpctl_k_dot3_power_pse_max, /**< `(I,W)` 802.3BT maximum available power */
+
 	lldpctl_k_port_vlan_pvid = 1500, /**< `(I)` Primary VLAN ID */
 	lldpctl_k_port_vlans, /**< `(AL)` List of VLAN */
 	lldpctl_k_vlan_id, /**< `(I)` VLAN ID */
@@ -778,6 +843,7 @@ typedef enum {
 	lldpctl_k_med_power_val, /**< `(I,W)` LLDP MED power value */
 
 	lldpctl_k_mgmt_ip = 3000,	/**< `(S)` IP address */
+	lldpctl_k_mgmt_iface_index = 30001,	/**< `(I)` Interface index */
 
 	lldpctl_k_tx_cnt = 4000,	/**< `(I)` tx cnt. Only works for a local port. */
 	lldpctl_k_rx_cnt,	/**< `(I)` rx cnt. Only works for a local port. */
